@@ -1,15 +1,16 @@
 #!@SH@
 ##
-##  Shiela - CVS Access Control and Logging Facility
+##  OSSP shiela - CVS Access Control and Logging Facility
 ##  Copyright (c) 2000-2002 Ralf S. Engelschall <rse@engelschall.com>
+##  Copyright (c) 2000-2002 The OSSP Project <http://www.ossp.org/>
 ##
-##  This file is part of Shiela, an access control and logging
+##  This file is part of OSSP shiela, an access control and logging
 ##  facility for Concurrent Versions System (CVS) repositories
-##  which can be found at http://www.ossp.org/pkg/shiela/.
+##  which can be found at http://www.ossp.org/pkg/tool/shiela/.
 ##
 ##  This program is free software; you can redistribute it and/or
-##  modify it under the terms of the GNU General Public  License 
-##  as published by the Free Software Foundation; either version 
+##  modify it under the terms of the GNU General Public  License
+##  as published by the Free Software Foundation; either version
 ##  2.0 of the License, or (at your option) any later version.
 ##
 ##  This program is distributed in the hope that it will be useful,
@@ -17,15 +18,15 @@
 ##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 ##  General Public License for more details.
 ##
-##  You should have received a copy of the GNU General Public License 
+##  You should have received a copy of the GNU General Public License
 ##  along with this file; if not, write to the Free Software
 ##  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 ##  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
 ##
-##  shiela-install: Shiela repository install program (syntax: Bourne-Shell)
+##  shiela-install.sh: repository install program (syntax: Bourne-Shell)
 ##
 
-version="0.9.2 (19-Aug-2002)"
+version="1.0.0"
 
 prefix="@prefix@"
 bindir="@bindir@"
@@ -84,16 +85,17 @@ case $TERM in
         ;;
 esac
 
-echo "This is ${term_bold}Shiela Setup${term_norm}, Version ${term_bold}${version}${term_norm}"
-echo "Copyright (c) 2000 Ralf S. Engelschall <rse@engelschall.com>"
+echo "This is ${term_bold}OSSP shiela Setup${term_norm}, Version ${term_bold}${version}${term_norm}"
+echo "Copyright (c) 2000-2002 Ralf S. Engelschall <rse@engelschall.com>"
+echo "Copyright (c) 2000-2002 The OSSP Project <http://www.ossp.org/>"
 echo ""
 
 echo "${term_bold}PARAMETER DETERMINATION${term_norm}"
 cat <<EOT
 
-This utility helps you to initially setup Shiela for a particular CVS
+This utility helps you to initially setup OSSP shiela for a particular CVS
 repository. It asks you a few questions in order to establish an initial
-Shiela configuration. This can be adjusted later without problems. Only
+OSSP shiela configuration. This can be adjusted later without problems. Only
 the questions marked with (U) ask for details which are actually used
 immediately and so have to be correctly entered already now. All other
 questions ask just for informational (I) details which do not harm if
@@ -295,18 +297,6 @@ if [ ".$V_tool_perl" = . ]; then
 fi
 query U tool_perl
 
-if [ ".$V_tool_cvs" = . ]; then
-    V_tool_cvs="cvs"
-    for path in $paths; do
-        path=`echo $path | sed -e 's;/*$;;'`
-        if [ $minusx "$path/cvs" ] && [ ! -d "$path/cvs" ]; then
-            V_tool_cvs="$path/cvs"
-            break
-        fi
-    done
-fi
-query U tool_cvs
-
 if [ ".$V_tool_sendmail" = . ]; then
     V_tool_sendmail="sendmail"
     for path in $paths; do
@@ -319,29 +309,79 @@ if [ ".$V_tool_sendmail" = . ]; then
 fi
 query U tool_sendmail
 
+if [ ".$V_tool_diff" = . ]; then
+    V_tool_diff="diff"
+    for path in $paths; do
+        path=`echo $path | sed -e 's;/*$;;'`
+        if [ $minusx "$path/diff" ] && [ ! -d "$path/diff" ]; then
+            V_tool_diff="$path/diff"
+            break
+        fi
+    done
+fi
+query U tool_diff
+
+if [ ".$V_tool_xdelta" = . ]; then
+    V_tool_xdelta="xdelta"
+    for path in $paths; do
+        path=`echo $path | sed -e 's;/*$;;'`
+        if [ $minusx "$path/xdelta" ] && [ ! -d "$path/xdelta" ]; then
+            V_tool_xdelta="$path/xdelta"
+            break
+        fi
+    done
+fi
+query U tool_xdelta
+
+if [ ".$V_tool_uuencode" = . ]; then
+    V_tool_uuencode="uuencode"
+    for path in $paths; do
+        path=`echo $path | sed -e 's;/*$;;'`
+        if [ $minusx "$path/uuencode" ] && [ ! -d "$path/uuencode" ]; then
+            V_tool_uuencode="$path/uuencode"
+            break
+        fi
+    done
+fi
+query U tool_uuencode
+
+if [ ".$V_tool_cvs" = . ]; then
+    V_tool_cvs="cvs"
+    for path in $paths; do
+        path=`echo $path | sed -e 's;/*$;;'`
+        if [ $minusx "$path/cvs" ] && [ ! -d "$path/cvs" ]; then
+            V_tool_cvs="$path/cvs"
+            break
+        fi
+    done
+fi
+query U tool_cvs
+
 CVS_VERSION=`$V_tool_cvs --version |\
              grep "Concurrent Versions System (CVS)" |\
              sed -e 's;^.*(CVS) ;;' -e 's; .*$;;'`
-if [ ".`$V_tool_cvs --version | grep OSSP`" != . ]; then
-    CVS_VENDOR=OSSP
+if [ ".`$V_tool_cvs --version | grep RSE`" != . ]; then
+    CVS_VENDOR=RSE
 else
-    CVS_VENDOR=OpenAvenue
+    CVS_VENDOR=CVSHome.org
 fi
 case $CVS_VERSION in
-   1.10.[789]* | 1.10.1[0123456789]* | 1.11.* ) 
+   1.10.[789]* | 1.10.1[0123456789]* | 1.11.* )
        ;;
-   * ) 
+   * )
        echo "ERROR: CVS has to be at least version 1.10.7"
-       exit 1 
+       exit 1
        ;;
 esac
 case $CVS_VENDOR in
-    OSSP ) 
+    RSE )
        ;;
-    * ) 
+    * )
        echo "WARNING: You are using a stock CVS version from $CVS_VENDOR!"
-       echo "         This means that not all Shiela functionality is available".
-       echo "         for you. Please consider upgrading to the OSSP CVS version.".
+       echo "         This means that not all OSSP shiela functionality is available"
+       echo "         for you. We recommend to use the OpenPKG CVS version with"
+       echo "         the enhancement patchset from Ralf S. Engelschall applied."
+       echo "         [see http://www.openpkg.org/ for OpenPKG]"
        echo ""
        ;;
 esac
@@ -365,16 +405,17 @@ query U shiela_local
 
 cat >$tmpdir/shiela.cfg <<EOT
 ##
-##  Shiela - CVS Access Control and Logging Facility
-##  Copyright (c) 2000 Ralf S. Engelschall <rse@engelschall.com>
+##  OSSP shiela - Access Control and Logging Facility for CVS
+##  Copyright (c) 2000-2002 Ralf S. Engelschall <rse@engelschall.com>
+##  Copyright (c) 2000-2002 The OSSP Project <http://www.ossp.org/>
 ##
-##  This file is part of Shiela, an access control and logging
-##  facility for Concurrent Versions System (CVS) repositories 
-##  which can be found at http://www.ossp.org/pkg/shiela/.
+##  This file is part of OSSP shiela, an access control and logging
+##  facility for Concurrent Versions System (CVS) repositories
+##  which can be found at http://www.ossp.org/pkg/tool/shiela/.
 ##
 ##  This program is free software; you can redistribute it and/or
-##  modify it under the terms of the GNU General Public  License 
-##  as published by the Free Software Foundation; either version 
+##  modify it under the terms of the GNU General Public  License
+##  as published by the Free Software Foundation; either version
 ##  2.0 of the License, or (at your option) any later version.
 ##
 ##  This program is distributed in the hope that it will be useful,
@@ -382,14 +423,21 @@ cat >$tmpdir/shiela.cfg <<EOT
 ##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 ##  General Public License for more details.
 ##
-##  You should have received a copy of the GNU General Public License 
+##  You should have received a copy of the GNU General Public License
 ##  along with this file; if not, write to the Free Software
 ##  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 ##  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
 ##
-##  shiela.cfg: Shiela configuration (syntax: Shiela C-style)
+##  shiela.cfg: run-time configuration (syntax: OSSP shiela C-style)
 ##
 
+Environment {
+    Program sendmail ${V_tool_sendmail};
+    Program cvs      ${V_tool_cvs};
+    Program diff     ${V_tool_diff};
+    Program uuencode ${V_tool_uuencode};
+};
+
 Project {
     Tag     ${V_project_tag};
     Name    "${V_project_name}";
@@ -403,14 +451,9 @@ Project {
     };
 };
 
-Environment {
-    CVS      ${V_tool_cvs};
-    Sendmail ${V_tool_sendmail};
-};
-
 Repository {
     Tag     ${V_repos_tag};
-    Name    "${V_repos_name}"; 
+    Name    "${V_repos_name}";
     Contact ${V_repos_contact};
     Home    ${V_repos_home};
     Host    ${V_repos_host};
@@ -456,8 +499,8 @@ echo ""
 echo "${term_bold}SHIELA CONFIGURATION${term_norm}"
 cat <<EOT
 
-Initial "shiela.cfg" and "shiela.msg" files were generated for you. 
-Before Shiela is installed and activated with these configuration files, 
+Initial "shiela.cfg" and "shiela.msg" files were generated for you.
+Before OSSP shiela is installed and activated with these configuration files,
 you have the chance to adjust them in your editor.
 
 EOT
@@ -516,13 +559,13 @@ cvs_file () {
 }
 
 run rm -rf CVSROOT
-run cvs -Q -q -d${V_repos_path} co CVSROOT 
+run cvs -Q -q -d${V_repos_path} co CVSROOT
 run cd CVSROOT
 
 if [ ".$V_shiela_local" = .yes ]; then
     cvs_file tst shiela
     run "cp $V_tool_shiela ."
-    run chmod 755 shiela 
+    run chmod 755 shiela
     cvs_file add shiela
     V_tool_shiela="\$CVSROOT/CVSROOT/shiela"
 fi
@@ -598,17 +641,17 @@ else
     fi
 fi
 echo ""
-run "$V_tool_cvs commit -m 'Add Shiela -- CVS Access Control and Logging Facility' ."
+run "$V_tool_cvs commit -m 'Add OSSP shiela -- Access Control and Logging Facility for CVS' ."
 run cd ..
 run rm -rf CVSROOT
 
 cat <<EOT
 
-Ok, your $V_repos_path/CVSROOT/ area was modified to now use Shiela for
-access control and logging. You can try it out by checking out CVSROOT
-yourself and modify some files. You should receive an Email for every
-modification. Then especially adjust "shiela.cfg" for your particular
-repository layout.
+Ok, your $V_repos_path/CVSROOT/ area was modified to now use OSSP shiela
+for access control and logging. You can try it out by checking out
+CVSROOT yourself and modify some files. You should receive an Email
+for every modification. Then especially adjust "shiela.cfg" for your
+particular repository layout.
 
 EOT
 
